Edited by:

Gregoire P. Millet,

University of Lausanne, Switzerland

Reviewed by:

Chris R. Abbiss,

Edith Cowan University, Australia

Davide Viggiano,

University of Molise, Italy

\*Correspondence:

Jean-Benoît Morin

[jean-benoit.morin@unice.fr](mailto:jean-benoit.morin@unice.fr)

Specialty section:

This article was submitted to

Exercise Physiology,

a section of the journal

Frontiers in Physiology

Received: 02 September 2016

Accepted: 20 December 2016

Published: 09 January 2017

Citation:

Jiménez-Reyes P, Samozino P,

Brughelli M and Morin J-B (2017)

Effectiveness of an Individualized

Training Based on Force-Velocity

Profiling during Jumping.

Front. Physiol. 7:677.

[doi: 10.3389/fphys.2016.00677](https://doi.org/10.3389/fphys.2016.00677)

[ORIGINAL RESEARCH](http://www.frontiersin.org/Physiology/editorialboard)
[published: 09 January 2017](http://www.frontiersin.org/Physiology/editorialboard)
[doi: 10.3389/fphys.2016.00677](https://doi.org/10.3389/fphys.2016.00677)

# Effectiveness of an Individualized Training Based on Force-Velocity Profiling during Jumping

[Pedro Jiménez-Reyes](http://loop.frontiersin.org/people/277427/overview) \[1\] [, Pierre Samozino](http://loop.frontiersin.org/people/275146/overview) \[2\] [, Matt Brughelli](http://loop.frontiersin.org/people/275552/overview) \[3\] [and Jean-Benoît Morin](http://loop.frontiersin.org/people/50242/overview) \[3, 4\]

1 Faculty of Sport, Catholic University of San Antonio, Murcia, Spain, 2 Laboratoire Interuniversitaire de Biologie de la motricité
(EA7424), University of Savoie Mont Blanc, Le Bourget du Lac, France, \[3\] Sports Performance Research Institute New Zealand
(SPRINZ), Auckland University of Technology, Auckland, New Zealand, \[4\] Université Côte d’Azur, LAMHESS, Nice, France

Ballistic performances are determined by both the maximal lower limb power output
(Pmax) and their individual force-velocity (F-v) mechanical profile, especially the F-v
imbalance (FVimb): difference between the athlete’s actual and optimal profile. An
optimized training should aim to increase Pmax and/or reduce FVimb. The aim of this study
was to test whether an individualized training program based on the individual F-v profile

would decrease subjects’ individual FVimb and in turn improve vertical jump performance.

FVimb was used as the reference to assign participants to different training intervention

groups. Eighty four subjects were assigned to three groups: an “optimized” group divided
into velocity-deficit, force-deficit, and well-balanced sub-groups based on subjects’
FVimb, a “non-optimized” group for which the training program was not specifically based
on FVimb and a control group. All subjects underwent a 9-week specific resistance

training program. The programs were designed to reduce FVimb for the optimized groups
(with specific programs for sub-groups based on individual FVimb values), while the

non-optimized group followed a classical program exactly similar for all subjects. All
subjects in the three optimized training sub-groups (velocity-deficit, force-deficit, and
well-balanced) increased their jumping performance (12.7 ± 5.7% ES = 0.93 ± 0.09,

14.2 ± 7.3% ES = 1.00 ± 0.17, and 7.2 ± 4.5% ES = 0.70 ± 0.36, respectively)

with jump height improvement for all subjects, whereas the results were much more

variable and unclear in the non-optimized group. This greater change in jump height
was associated with a markedly reduced FVimb for both force-deficit (57.9 ± 34.7%
decrease in FVimb) and velocity-deficit (20.1 ± 4.3%) subjects, and unclear or small
changes in Pmax (−0.40 ± 8.4% and +10.5 ± 5.2%, respectively). An individualized
training program specifically based on FVimb (gap between the actual and optimal F-v
profiles of each individual) was more efficient at improving jumping performance (i.e.,
unloaded squat jump height) than a traditional resistance training common to all subjects

regardless of their FVimb. Although improving both FVimb and Pmax has to be considered

to improve ballistic performance, the present results showed that reducing FVimb without
even increasing Pmax lead to clearly beneficial jump performance changes. Thus, FVimb

could be considered as a potentially useful variable for prescribing optimal resistance

training to improve ballistic performance.

Keywords: jumping, ballistic training, explosive performance, resistance strength training, maximal power output

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 1 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

INTRODUCTION

Advancements in strength and conditioning methodologies
alongside evolution in physical demands of competition in
sports such as rugby, football, volleyball, basketball, or athletics,
have led to an increased relevance of high-intensity, ballistic
actions. Physical performance in these kinds of sports is clearly
determined by high levels of force, power, and velocity during
ballistic movements such as sprints, changes of direction, or
jumps (Cronin and Sleivert, 2005; Cormie et al., 2010).
Ballistic performances, notably jumping, can be defined as
the ability to accelerate body mass, both as much as possible
and within the shortest time possible (Samozino et al., 2012).
From a mechanical point of view, ballistic push-off performance
is thus directly related to the net mechanical impulse produced
onto the ground (Winter, 2005). The capability to develop a high
net impulse during one lower limb push-off has been associated
with muscular mechanical power output capabilities (Newton
and Kraemer, 1994; Yamauchi and Ishii, 2007; Samozino et al.,
2008; Frost et al., 2010; McBride et al., 2010). Numerous
studies have highlighted neuromuscular power as the primary
variable related to ballistic performance, yet this analysis only
provides a partial representation of the athlete’s true maximal
mechanical capabilities (Cronin and Sleivert, 2005). Specifically,
in the recent years, a new paradigm supports the fact that
although ballistic performance such as jumping height is largely
determined by maximal power output (Pmax) that lower limbs
can generate (Yamauchi and Ishii, 2007), it is also influenced
by the individual combination of the underlying force and
velocity mechanical outputs, known as force-velocity (F-v) profile
(Samozino et al., 2012, 2014; Morin and Samozino, 2016). Thus,
the inclusion of F-v relationship and their contribution to ballistic
performance may provide a more accurate and integrative
mechanical representation of the athlete’s maximal capabilities
(Samozino et al., 2012), since they encompass the entire forcevelocity spectrum, from the theoretical maximal force (F0) to the
theoretical velocity (v0) capabilities (Morin and Samozino, 2016).
As shown theoretically (Samozino et al., 2008, 2012) and
confirmed experimentally (Samozino et al., 2014), there is,
for each individual, an optimal F-v profile that maximizes
the ballistic performance (e.g., vertical or inclined jumping)
and represents the optimal balance between force and velocity
qualities for these movements (Samozino et al., 2012, 2014). The
relative difference between actual and optimal F-v profiles for
a given individual represents the magnitude and the direction
of the unfavorable balance between force and velocity qualities
(i.e., force-velocity imbalance, FVimb in %), which makes possible
the individual determination of force or velocity deficit. The
actual individual F-v profile and Pmax can be easily determined
from a series of loaded vertical jumps (Samozino et al., 2008,
2014; Jiménez-Reyes et al., 2014, 2016; Giroux et al., 2015,
2016), while the optimal F-v profile can be computed using
previously proposed equations based on a biomechanical model
(Samozino et al., 2012, 2014). For a given Pmax, vertical jump
performance has been shown to be negatively correlated to FVimb,
which supports the importance of considering this individual
characteristic in addition to Pmax when designing training

programs to improve ballistic performance (Samozino et al.,
2012, 2014; Morin and Samozino, 2016).
Quantifying FVimb on an individual basis could therefore help
improve the effectiveness of training prescription by adapting
it to each athlete’s individual needs. In theory, this would lead
to improved ballistic performance through an effective shift in
the individual actual F-v profile toward the optimal value (FVimb
reduction), and/or an increase in Pmax (Samozino et al., 2014).
For instance, the individual jumping F-v profile has been shown
sensitive to training over different periods of a season in highlevel rugby players (de Lacey et al., 2014), and to training history
and sport activities of various populations (Vuk et al., 2012;
Markovic et al., 2013; Samozino et al., 2014; Giroux et al., 2016).
Therefore, we can reasonably expect (personal unpublished pilot
observations) that the individual F-v profile would respond to
specific training. Moreover, the individual jumping F-v profile
has been shown sensitive to the kind of strength training
performed (Cormie et al., 2010).
Some traditional training methods have been considered for
power improvement, such as: power and ballistic training (e.g.,
Wilson et al., 1993; Newton et al., 1996; Cormie et al., 2007,
2010; Argus et al., 2011; Markovic et al., 2011; Sheppard et al.,
2011; Zaras et al., 2013), heavy-load training (focusing more on
strength; e.g., Gorostiaga et al., 1999; Harris et al., 2000; Chelly
et al., 2009; Rønnestad et al., 2012, 2016) and combined training
(strength-power training; e.g., Wilson et al., 1993; McBride et al.,
2002; Kotzamanidis et al., 2005; Cormie et al., 2007, 2010;
Smilios et al., 2013; Zaras et al., 2013). This kind of global
power training prescription similar for all athletes resulted in
contrasting findings as to the effects on jumping performance
(e.g., Wilson et al., 1993; Gorostiaga et al., 1999; Harris et al.,
2000; McBride et al., 2002; Kotzamanidis et al., 2005; Cormie
et al., 2007, 2010; Chelly et al., 2009; Rønnestad et al., 2012,
2016; Smilios et al., 2013; Zaras et al., 2013), likely because
of the various levels and F-v characteristics of the populations
tested. Indeed, a training program leading to improve Pmax while
increasing FVimb could result in a lack of change, or even a
decrease in jumping performance. We propose here that tailoring
the training prescription to the athlete’s individual F-v profile
would improve the effectiveness of such training. This innovative
approach will be designed as follows.
In the case of a force deficit, training should be aimed
to increase Pmax while decreasing FVimb, by increasing force
capabilities (F0) as a priority (Samozino et al., 2012). Previous
studies clearly shows the effectiveness of strength training aiming
at specifically increasing maximal force capabilities (Cormie et al.,
2007, 2010; Rønnestad et al., 2012, 2016; Zaras et al., 2013).
They have shown improvements in maximal strength parameters
(e.g., 1RM, 1RM/BM ratio) through trainings involving the
use of high loads (>70% RM), in order to achieve the
maximal neuromuscular adaptations, in periods ranging from
6 to 12 weeks. Note that these training-induced adaptations
were not systematically associated to ballistic performance
improvements.
At the other end of the F-v spectrum, in case of a velocity
deficit, training should aim to increase Pmax by improving
maximal velocity capabilities (i.e., capacity to produce force at

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 2 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

very high contraction velocities). It should be oriented toward
maximal velocity efforts during high accelerated movements with
minimal or null braking phase, for example a throw at the end of
a lift and displacing low (\<30% RM) or negative loads (Argus
et al., 2011; Markovic et al., 2011; Sheppard et al., 2011). The
effects of this type of training, commonly referred to as ballistic,
can be observed in studies where protocols with a removed
deceleration phase during liftings have been shown more effective
(Newton et al., 1996; Cormie et al., 2010). These studies and
others (Markovic and Jaric, 2007; Argus et al., 2011; Markovic
et al., 2011, 2013; Sheppard et al., 2011) show how employing
loads lower than body mass (referred to as negative loads) may
result in a training-induced shift in force-time curves and forcevelocity relationships toward more velocity-related capabilities
(Djuric et al., 2016).
Finally, in case of a low deficit (i.e., actual F-v profile close
to the computed optimal profile), the training program should
target a balanced combination of force, velocity, and power in
order to shift the entire F-v relationship to the right, and so to
increase Pmax as a priority (Wilson et al., 1993; Harris et al., 2000;
McBride et al., 2002; Kotzamanidis et al., 2005; e.g., Cormie et al.,
2007; de Villarreal et al., 2011) while maintaining the F-v profile
close to the optimal value (and thus FVimb close to 0%). The
effects of studies aiming to both increase maximal power and shift
the entire F-v curve show how combining a wide range of loads
(heavy, optimal, and ballistic loads) is an appropriate stimulus
(Harris et al., 2000; McBride et al., 2002; Kotzamanidis et al.,
2005; Cormie et al., 2007).
In light of the three latter paragraphs showing the sensitivity
of the F-v profile to specific training programs can result in
either maximal force or velocity capabilities improvements, it
is reasonable to hypothesize that specific resistance training
programs can be designed on an individual basis to both reduce
FVimb (i.e., to increase preferably the F0 or v0 component of an
individual’s F-v profile and shift it toward his optimal profile) and
increase Pmax (in case of well-balanced F-v profile). This is what
we will term “optimized training” or “individualized training
based on FVimb” in the present study.
Theory (Samozino et al., 2012, 2014) and case studies (Morin
and Samozino, 2016) show that, ceteris paribus, such a training
approach could result in a decreased FVimb and in turn, in an
improved jumping performance. To date no direct controlled
experiment has been performed to confirm the effectiveness of
this optimized training approach.
The aim of this study was to experimentally test the
hypothesis that an individualized training program based on
the imbalance in the F-v profile of each individual is more
effective in improving jump performance than a traditional
resistance training common to all subjects and designed without
taking account of individual differences in the initial F-v profiles
and imbalances. We also hypothesized that in such a case, the
improved vertical jump performance would result from both
a shift in the F-v profile toward the optimal and an increase
in Pmax, while the “non-optimized” group would only increase
Pmax. Note that vertical jump height was used here as the index
of performance since it represents the archetype of ballistic

movements.

MATERIALS AND METHODS

Subjects
Eighty-four trained athletes (age = 23.1 ± 4.4 year, body
mass = 75.5 ± 8.5 kg, stature = 1.79 ± 0.046 m) gave their
written informed consent to participate in this study, which
was approved by the local ethical committee of the Catholic
University of San Antonio (Murcia) in agreement with the
Declaration of Helsinki. All subjects were semi-professional
soccer and rugby players. All athletes had a strength-training
background ranging from 1 to more than 3 years, were highly
trained (average weekly training volume of 12 h at the time of the
study), and familiar with the testing procedures.

Testing Procedure and Data Processing
F-v Relationships of Lower Limb Neuromuscular
System in SJ
To determine individual F-v relationships, each subject
performed vertical maximal SJ without loads and against five to
eight extra loads ranging from 17 to 87 kg in a randomized order.
The test was performed on a Smith machine (Multipower Fitness
Line, Peroga, Spain) that allows a smooth vertical displacement
of the bar along a fixed vertical path. Before each SJ condition
with no additional load, participants were instructed to stand
up straight and still on the center of the jumping area. They
kept their arms on their hips for jumps without load and on the
bar for loaded jumps, this hand position remaining the same
during the entire movement. Subjects were asked to maintain
their individual starting position (∼90 \[◦\] knee angle) for about 2 s
and then apply force as fast as possible and jump for maximum
height. Countermovement was verbally forbidden and carefully
checked. If all these requirements were not met, the trial was
repeated. Two valid trials were performed with each load with
2 min of recovery between trials and 4–5 min between loads
condition.

Mean mechanical parameters were calculated for each loading
condition using Samozino’s method (Samozino et al., 2008),
based on Newton’s second law of motion. This method

establishes that mean force (F), velocity (v), and power (P) can
be calculated during a vertical jump from jump height and squat
jump positions measurement. Jump height was obtained using
an OptoJump optical measurement system (Microgate, Bolzano,
Italy). Force, velocity and power were calculated using three
equations considering only simple input variables: body mass,
jump height and push-off distance. The latter corresponds to the
distance covered by the center of mass during push-off, i.e., to the
extension range of lower limbs from the starting position to takeoff (Samozino et al., 2008), and was a priori measured for each
subject by the difference between the extended lower limb length
(iliac crest to toes with plantar flexed ankle) and the height in the
individual standardized starting position (iliac crest to ground
vertical distance).
F-v relationships were determined using the best trials of each
loading condition and least squares linear regressions. F-v curves
were extrapolated to obtain F0 (then normalized to body mass)
and v0, which respectively correspond to the intercepts of the
F-v curve with the force and velocity axis. The F-v profile, that

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 3 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

is the slope of the F-v linear relationship was then computed
from F0 and v0 according to Samozino et al. (2012). Values of
Pmax (normalized to body mass) were determined as: Pmax =
F0·v0/4 (Samozino et al., 2012, 2014). From Pmax and hpo values,
there is an individual theoretical optimal F-v profile (normalized
to body mass, in N.s.kg \[−\]\[1\] .m \[−\]\[1\] ) maximizing vertical jumping
performance that was computed for each subject using equations
proposed by Samozino et al. (2012). The F-v imbalance (FVimb,
in %), was then individually computed as recently proposed by
Samozino et al. (2014):

SFv
Fvimb = 100. |1 − SFv opt \[|\]

A FVimb value around 0% indicates a F-v proifile equal to 100%
of the optimal proifile (perfect balance between force and velocity
qualities), whereas a F-v profile value higher or lower than the
optimal indicates a profile too oriented toward force or velocity
capabilities, respectively.

Experimental Design
The present study used a longitudinal pre-post design with
testing sessions separated by 9 weeks. All tests were conducted
at the same time of day, from 17:00 to 21:00. Each subject
underwent anthropometric assessment and performed loaded
squat jumps (SJ) to determine the individual force-velocity (Fv) relationships, Pmax values and F-v imbalance (computations
are detailed in the next section). FVimb was then used as the
reference to assign participants to different training intervention
groups and sub-groups. Since the main line of the approach
tested is that performance improvement would result from
increasing Pmax and/or decreasing FVimb (Morin and Samozino,
2016), and given our main hypothesis, FVimb was the criterion
used for designing an individualized training program in this
study.
After initial testing of their individual F-v properties,
participants were assigned to optimized training group \[force
deficit (FD) sub-group (n = 22; body mass = 72.2 ± 8.3 kg,
stature = 1.78 ± 0.062 m\], velocity deficit (VD) sub-group (n
= 18; body mass = 80.6 ± 9.6 kg, stature = 1.811 ± 0.042 m),
well-balanced (WB) sub-group (n = 6; body mass = 75.6 ± 4.9
kg, stature = 1.783 ± 0.049 m), a non-optimized training group
(NO, n = 18; body mass = 77.0 ± 6.6 kg, stature = 1.791 ± 0.033
m), or a control group (CG, n = 20; body mass = 73.0 ± 7.9 kg,
stature = 1.785 ± 0.032 m). The training program was adjusted
to the needs of participants in the optimized group according to
the FVimb. As a consequence, the training program was slightly
different regarding loading but similar in volume among groups,
and all subjects were familiar with the exercises used. The training
intervention was performed at the middle of the competitive
season for all participants.
During the 9 weeks of training, the FD sub-group performed
mainly force-oriented (very high loads) training, while the
VD sub-group performed velocity-oriented (ballistic, very high
velocity of limbs extension) training. The WB sub-group followed
a training program covering the entire force-velocity spectrum
in equal proportions: heavy loads, power, and ballistic training.

All the subjects of the NO training group followed the latter
kind of training, independently from each subject’s FVimb. NO
group was composed by 18 subjects with different initial F-v
profile and FVimb before the training intervention (10 with force
deficit and 8 with velocity deficit), with the purpose to match the
distribution of the optimized groups as much as possible. Finally,
the CG maintained their normal level of activity throughout the
duration of the study without performing any kind of strength
training. For each subject, jumping F-v profile and performance
were tested exactly 1 week before the first training session (pretraining), and again 1 week after the completion of the 9-week
training (post-training). The training intervention for all groups
was organized following recommendations from the literature:
more than three sets/session (Rhea et al., 2002) and a frequency of
2–3 sessions/week for strength (Rhea et al., 2003; Peterson et al.,
2004), including plyometrics (Markovic, 2007). All intervention
groups performed 18 sets/week (details in **Tables 1, 2** ), which is
similar to previous research (Harris et al., 2000; McBride et al.,
2002; Cormie et al., 2007, 2010; Argus et al., 2011; Markovic
et al., 2011; Sheppard et al., 2011). The training dose required
to develop strength is generally described as high frequency (3–5
weekly sessions per muscle group), moderate volume (3–6 sets ×
2–6 repetitions × load mass), and high intensity (85–100% onerepetition maximum (1RM) and non-ballistic nature of strength
training exercises; while power differs mainly in the intensity (20–
70% 1RM) and high movement velocity (i.e., explosive-ballistic;
Baechle and Earle, 2000; Fleck and Kraemer, 2004).

TABLE 1 | Force-velocity imbalance categories, thresholds, and
associated resistance training load ratios.

FVimb categories F-v profile in % of optimal Training loads ratio\*
thresholds (%)

High force deficit \<60 3 Strength

2 Strength-power

1 Power

Low force deficit 60–90 2 Strength

2 Strength-power

2 Power

Well-balanced >90–110 1 Strength

1 Strength-power

2 Power

1 Power-speed

1 Speed

Low velocity deficit >110–140 2 Speed

2 Power-speed

2 Power

High velocity deficit >140 3 Speed

2 Power-speed

1 Power

FVimb, F-v imbalance. \*Ratio based on six exercises/wk, three sets/exercise and 18

sets/wk.

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 4 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

TABLE 2 | Loading target for the F-v spectrum and exercises and training

loads for each exercise.

Loading focus/target Exercises Training loads

Strength Back squat 80–90% 1RM

Leg press 90–95% 1RM

Deadlift 90–95% 1RM

Strength-power Clean pull 80% 1RM

Deadlift 80% 1RM

SJ >70% of BW

CMJ >80% of BW

Power SJ 20–30% of BW

CMJ 35–45% of BW

Single leg SJ BW

Single leg CMJ 10% of BW

Clean pull jump 65% 1RM

Power-speed Depth jumps

SJ BW

CMJ 10% of BW

Maximal Vertical Box Jump

Speed Maximal Roller Push-off \<BW

CMJ with arms BW

RM, repetition maximum; SJ, Squat Jump; BW, body weight; CMJ, Countermovement

Jump.

Training Intervention
Due to the pilot feature of this study, we designed
straight-forward and simple training programs in the context
of a first attempt to test our hypotheses. All training programs
involved two sessions per week, each separated by 48 h of
recovery. Subjects refrained from any additional lower body
resistance training outside the experimental training throughout
the course of the study. Their competitive activities and
sport-specific training was maintained.
Considering the aforementioned elements on the specificity
of training to improve the specific components of maximal force
or velocity parts of the F-v spectrum (e.g., Wilson et al., 1993;
Newton et al., 1996; Harris et al., 2000; McBride et al., 2002;
Cormie et al., 2007, 2010; Argus et al., 2011; Markovic et al., 2011;
Sheppard et al., 2011; Rønnestad et al., 2012, 2016; Zaras et al.,
2013), the FD and VD training groups were established according
to individuals’ FVimb. For each one of these sub-groups, we
considered not only the type of deficit (either in force or in
velocity), but also its magnitude. Therefore, in each sub-group,
the training program was established according to specific FVimb
thresholds, as detailed in ( **Table 1** ).
According to previous findings showing improvements in
maximal strength, power and ballistic performance after specific
training (e.g., Cormie et al., 2007, 2010), the individualized
training programs proposed here included maximal efforts and
were mainly designed by setting the loads to vary the movement
velocity, and in turn to target the different parts of the F-v curve.
For example, “Strength” exercises used high loads ∼ F0 moved at

low v such as >80% of one repetition maximum in back squat
whereas “Speed” exercises used F of ∼body mass moved at high
v. The high v was greater than a squat jump, using the stretchshortening cycle (e.g., CMJ) or assisted/low resistance push-offs
(e.g., band assisted SJ or horizontal assisted roller).

Statistical Analysis
All data are presented as mean ± SD. In order to clearly assess
the practical meaning of the results, data were analyzed using the
magnitude-based inference approach (Hopkins et al., 2009).
Within-group difference in pre and post-training jump height,
F-v profile in (%) of Optimal F-v, F0, and v0 were assessed using
standardized effect size (ES). Between-group (optimized group
vs. non-optimized group) differences in pre and post-training
jump height and F-v profile in (%) of Optimal F-v were also
assessed using standardized ES. The magnitude of the withingroup and between-group changes was interpreted by using
values of trivial (\< 0.20), small (0.20 to \< 0.60), moderate (0.60
to \< 1.20), large (1.20 to \< 2.00), and extremely large of the
between-athlete variation at pre (i.e., smallest worthwhile change,
SWC).
The probability that these differences actually exist was then
assessed via magnitude-based qualitative inferences (Batterham
and Hopkins, 2006). Qualitative inferences were based on
quantitative chances of benefit outlined in Hopkins et al. (2009).
Clinical chances are percentage chances that an observed effect
is clinically positive/trivial/negative e.g., (40/40/20%) means an
effect has 40% of chances to be positive, 40% to be trivial, and 20%
to be negative. Probabilities that differences were higher than,
lower than, or similar to the smallest worthwhile difference were
evaluated qualitatively as possibly, 25–74.9%; likely, 75–94.9%,
very likely, 95–99.5%; and most (extremely) likely, >99.5%.
Since the findings of present study could be used for athletes
considered in isolation, individual analyses were performed
to quantify for each variables and each group the number
of responders and no responders. Monitoring progression of
an athlete with performance requires taking into account the
magnitude of the SWC in performance and the uncertainty
or noise in the test result (Hopkins, 2004), SWC being
computed as one-fifth of the between-athlete standard deviation
(a standardized or Cohen effect size of 0.20, Hopkins, 2004).
Subjects were then considered as harmful (individual change \<
−1 SWC), trivial (from −1 SWC to +1 SWC) or beneficial (+1
SWC) responders.

RESULTS

Mean ± SD values for all performance and mechanical variables
pre and post training intervention are shown for all groups
and sub-groups in **Table 3**, along with within-group changes
qualitative inferences.
FD and VD sub-groups showed large and extremely large
changes in FVimb, respectively, whereas this change was unclear
for the WB group, who showed a small increase in Pmax ( **Table 3** ).
Contrastingly, the changes for the “non-optimized” group were
overall likely trivial, with a very high inter-subject variability
( **Table 3** ; **Figures 1**, **2** ). The most important improvements in

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 5 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

TABLE 3 | Changes in variables associated to Force-velocity profile in different groups.

Pre Post Post-pre Individual response

x¯ ± SD x¯ ± SD %� ± SD ES; ±90% CL Inference and probability Harmful/Trivial/Beneficial

~~F-v (%) OPTIMAL F-v~~

Force deficit 45.1 ± 14.3 68.8 ± 17.7 57.9 ± 34.7 1.60 ± 0.26 Large +ive most likely 1 – 0 – 21

Velocity deficit 130 ± 11.5 103 ± 6.3 −20.1 ± 4.3 −2.20 ± 0.26 Ext. Large –ive most likely 0 – 0 – 18

Well-balanced 101 ± 7.0 100 ± 1.4 −0.50 ± 6.7 −0.11 ± 0.20 Trivial unclear 3 – 1 – 2

Non-optimized 88.6 ± 38.1 81.8 ± 34.7 −5.54 ± 17.6 −0.17 ± 0.15 Trivial possibily 7 – 3 – 8

Control 77.9 ± 33.1 79.3 ± 34.5 1.91 ± 17.1 0.01 ± 0.08 Trivial most likely 1 – 14 – 5

~~Pmax (W·kg~~ \[−\]\[1\] ~~)~~

Force deficit 30.7 ± 5.6 30.5 ± 5.8 −0.40 ± 8.4 −0.04 ± 0.17 Trivial likely 7 – 12 – 3

Velocity deficit 24.2 ± 4.8 26.6 ± 5.0 10.5 ± 5.2 0.48 ± 0.08 Small +ive most likely 0 – 1 – 17

Well-balanced 23.9 ± 2.2 25.2 ± 2.2 5.53 ± 4.5 0.50 ± 0.33 Small +ive likely 0 – 1 – 5

Non-optimized 23.5 ± 3.5 24.0 ± 3.3 2.42 ± 6.1 0.13 ± 0.16 Trivial likely 5 – 3 – 10

Control 23.2 ± 2.5 23.4 ± 5.6 0.61 ± 15.7 0.09 ± 0.58 Trivial unclear 7 – 11 – 2

~~F0 (N·kg~~ \[−\]\[1\] ~~)~~

Force deficit 29.1 ± 4.1 35.9 ± 4.2 24.0 ± 10.8 1.60 ± 0.17 Large +ive most likely 0 – 2 – 20

Velocity deficit 43.4 ± 6.1 40.6 ± 5.2 −6.16 ± 3.3 −0.43 ± 0.10 Small -ive most likely 17 – 1 – 0

Well-balanced 38.5 ± 1.5 39.1 ± 1.9 1.76 ± 3.5 0.38 ± 0.64 Small +ive unclear 2 – 1 – 3

Non-optimized 34.1 ± 7.4 33.2 ± 7.1 −2.32 ± 6.8 −0.12 ± 0.13 Trivial likely 9 – 6 – 3

Control 31.9 ± 6.8 31.9 ± 7.0 0.21 ± 3.8 0.00 ± 0.06 Trivial most likely 2 – 17 – 1

~~v0 (m·s~~ \[−\]\[1\] ~~)~~

Force deficit 4.29 ± 0.93 3.44 ± 0.78 −18.9 ± 11.8 −0.88 ± 0.24 Moderate -ive most likely 21 – 0 – 1

Velocity deficit 2.21 ± 0.16 2.60 ± 0.17 17.9 ± 4.2 2.73 ± 0.21 Ext. Large +ive most likely 0 – 0 – 18

Well-balanced 2.48 ± 0.17 2.57 ± 0.11 3.70 ± 4.1 0.44 ± 0.41 Small +ive likely 1 – 1 – 4

Non-optimized 2.88 ± 0.72 3.00 ± 0.67 5.57 ± 11.9 0.17 ± 0.21 Trivial possibly 5 – 3 – 10

Control 3.05 ± 0.82 3.10 ± 1.25 1.18 ± 21.2 0.06 ± 0.36 Trivial unclear 3 – 16 – 1

~~JUMP HEIGHT (m)~~

Force deficit 0.323 ± 0.04 0.367 ± 0.04 14.2 ± 7.3 1.00 ± 0.17 Moderate +ive most likely 0 – 0 – 22

Velocity deficit 0.319 ± 0.06 0.357 ± 0.05 12.7 ± 5.7 0.93 ± 0.09 Moderate +ive most likely 0 – 0 – 18

Well-balanced 0.315 ± 0.03 0.338 ± 0.03 7.22 ± 4.5 0.70 ± 0.36 Moderate +ive very likely 0 – 0 – 6

Non-optimized 0.305 ± 0.04 0.312 ± 0.04 2.33 ± 4.7 0.14 ± 0.13 Trivial likely 1 – 10 – 7

Control 0.292 ± 0.04 0.288 ± 0.04 −1.43 ± 3.3 −0.09 ± 0.10 Trivial very likely 9 – 10 – 1

Values are mean ± standard deviation, percent change ± standard deviation and standardized effect size; ±90% confidence limits. ¯x, mean; SD, standard deviation, %∆, percent
change; ES, effect size; 90% CL, 90% confidence limits; Ext, extremely; +ive, positive effect; -ive, negative effect; Pmax, maximal power output; W, watt; kg, kilogramme; F0, theoretical
maximal force; N, newton; v0, theoretical maximal velocity; m, metre; s, second. Qualitative inferences are trivial (\<0.20), small (0.20 to \<0.60), moderate (0.60 to \<1.20), large (1.20 to
\<2.00) and extremely large moderate (>2.00): possibly, 25 to \<75; likely, 75 to \<95%; very likely, 95 to \<99.5%; most likely, >99.5. Positive, neutral and negative descriptors qualitatively
describe the change between post and pre values and its importance relative to the specific variable.

jump performance were observed in the intervention groups
(+7.2 to +14.2% on average, very likely to most likely very large
effects vs. trivial change of +2.3% for the non-optimized and
control group).
An individual approach of the study outcomes shows that in
the optimized group (including FD, VD, and WB sub-groups) all
the 46 subjects improved their jump height, and all of them but
one reduced their FVimb ( **Table 3** ). For the non-optimized group,
only 10 subjects out of 18 improved jump height and 11 out of 18
reduced their FVimb. Finally, in the control group, only 8 subjects
out of 20 subjects improved jump height and 12 out of 20 reduced
their FVimb.
In the optimized group (including FD, VD, WB sub-groups),
all the subjects were beneficial responders in jump height, and all
of them but one in FVimb ( **Table 3** ). Contrastingly, 7 subjects out
of 18 of the non-optimized group were beneficial responders for

jump height (8 out of 18 for FVimb) and 1 out of 20 in control
group (5 out of 20 in FVimb, **Table 3** ).
The results referring to between-groups differences showed
almost certain large (ES = 1.21–100/0/0) and moderate (ES =
0.73 100/0/0) differences in FVimb and jump height, respectively,
in favor of optimized group vs. non-optimized group, which
highlight the findings in our study.
As shown in **Table 3**, the changes for the non-optimized
and control groups were much more variable and the overall
magnitude less clear.

DISCUSSION

The aim of this study was to experimentally test the hypothesis
that an individualized training program based on the forcevelocity imbalance of each subject was more effective at

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 6 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

FIGURE 1 | (A) Individual Pre-Post changes in F-v profile for Optimized Group
and sub-groups. (B) Individual Pre-Post changes in F-v profile for
Non-Optimized and Control Group.

improving jump performance than a traditional resistance
training common to all subjects (designed without taking
account of individual differences in the initial F-v profiles and
imbalances). Our main hypothesis was that this individualized
and optimized training would result in a decreased imbalance for
each individual, and in turn a greater vertical jump performance.
The main findings of this study validate our initial hypothesis:
(i) an optimized and individualized training program specifically
addressing the FVimb is more efficient for improving jumping
performance (all subjects showed improvement in jump height)
than a traditional resistance training common to all subjects (10
subjects out of 18 improved), regardless of their force-velocity
imbalance and optimal force-velocity profile, (ii) for subjects with
an initial substantial FVimb (i.e., force or a velocity deficit) this
higher jump performance was associated with the sensitivity of
the force-velocity profile to the specific training program tailored
to the athlete’s individual needs, which has lead here to a reduced
F-v imbalance with no change in Pmax.
It is important to highlight that jump height improvements
were greater, and for a larger number of subjects, with a
training based on the F-v approach and FVimb as opposed to
traditional training. Although this is not a common practice
in the strength and conditioning field, its application could
be of high interest since the optimal F–v profile, which can

FIGURE 2 | (A) Individual Pre-Post changes in vertical jump height for
Optimized Group and sub-groups. (B) Individual Pre-Post changes in F-v
profile for Non-Optimized and Control Group.

be accurately determined, depends on individual characteristics
(limb extension, Pmax and different loaded squat jumps;
Samozino et al., 2012). Thus it could be a very easy to design
a training program with the focus on increasing Pmax and/or
decreasing FVimb (Morin and Samozino, 2016).
The main novelty of our results was that in order to improve
jump performance, not only should Pmax be considered, but
also the individual force-velocity profile. Indeed, changes in
Pmax were trivial or small in the FD and VD optimized subgroups, whereas changes in F0 and v0 were large and extremely
large. Contrastingly, the “one-size-fits-all” program with the nonoptimized group might not be an efficient training stimulus
for a group of individuals with different FVimb, thus different
training needs. Despite some inevitable limitations that will be
addressed at the end of this discussion, the novelty of the present
experimental study and the clear results obtained may bring
valuable additional knowledge and potential applications to sport
training practice toward a more individualized, specific, and
effective training monitoring and periodization.
Several studies have shown some positive effects of strength
training on improving vertical jump performance, although
with contradictory results, and inconsistancies in the training
prescription (e.g., heavy loads for all subjects; Gorostiaga et al.,
1999; Harris et al., 2000; McBride et al., 2002; Cormie et al., 2010;
de Villarreal et al., 2011; Losnegard et al., 2011; Rønnestad et al.,
2012, 2016), while other studies considered also light loads (e.g.,

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 7 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

Wilson et al., 1993; McBride et al., 2002; Cormie et al., 2007;
Zaras et al., 2013), or combined strength training (e.g., Wilson
et al., 1993; Toji et al., 1997; Harris et al., 2000; McBride et al.,
2002; Kotzamanidis et al., 2005; de Villarreal et al., 2011). Two
common features of these studies were that the same training
program was prescribed to all subjects and the great variability in
performance response to training (Wilson et al., 1993; Gorostiaga
et al., 1999; Harris et al., 2000; McBride et al., 2002; Kotzamanidis
et al., 2005; Cormie et al., 2007, 2010; Chelly et al., 2009; de
Villarreal et al., 2011; Losnegard et al., 2011; Rønnestad et al.,
2012, 2016; Smilios et al., 2013). In the present protocol, all the
subjects tested were sub-divided into specific sub-groups and
then assigned to a group-specific training program, which led
to a more appropriate training program and more efficient and
less variable results in terms of jump performance improvement
compared to the aforementioned studies. Each of these groups
will be discussed separately.

Force-Deficit Sub-group
For the FD sub-group, the specific heavy-load program resulted
in moderate to large increases in F0 (+24 ± 10.8% on average; ES
= 1.60 ± 0.23), FVimb reduction for all subjects but one (−57.9
± 34.7%; ES = 1.60 ± 0.26) and jump height (+14.2 ± 7.3%;
ES = 1.00 ± 0.17). Individual analysis showed that all subjects
improved jump height and all but one reduced FVimb, which
would support the great effectiveness of this kind of training
approach. Thus, as hypothesized, the selected exercises for this
group were likely effective for specifically shifting F-v profile in
accordance with initial FVimb showing a force-deficit ( **Table 3** ;
**Figures 1**, **2** ). These findings are in agreement with other studies
showing high-load training specificity (Wilson et al., 1993; Harris
et al., 2000; McBride et al., 2002; Cormie et al., 2010).
The large increase in F0 in the FD sub-group was associated
to an important increase in jump height since vertical jumping is
in the most force-dependent plane for a ballistic movement as
it encounters the maximal magnitude of negative gravitational
acceleration (Minetti, 2002; Samozino et al., 2012) meaning
an increase in F0 would influence jump height more than an
increase in v0 (Samozino et al., 2010). In line with this, the
FD group had “high” or “low/moderate” force deficits and thus
used mainly heavy load resistance training exercises ( **Tables 1,**
**2** ) which should have theoretically increased jump height and
principally via an increase in F0 (Harris et al., 2000; McBride et al.,
2002; Cormie et al., 2010; Losnegard et al., 2011; Rønnestad et al.,
2012, 2016).
The increase in F0 is observed here in parallel with a decrease
in v0, even if no interrelationships can be supported between
these two qualities, except the fact that when one of these qualities
is trained, the other is not. So, in present study, the maximal
strength improvement (F0) is not associated with the same kind
of increase in Pmax, which would have been the case if subjects
had kept their v0 value similar. Consequently, the performance
improvement can be only attributed to FVimb reduction, and not
to an increased Pmax, which is greater support for the interest
of considering FVimb in strength training focusing on improving
ballistic performance.

The possible explanatory mechanisms for these changes in
maximal force after the optimized training may include an
increased neural drive and enhanced intermuscular coordination

(McBride et al., 2002; Cormie et al., 2010), rate of motor
unit recruitment (size principle), and the activation of type
II muscle fibers and subsequent improvement in maximal
strength capabilities (Cormie et al., 2011). These changes may
also be associated with effective changes in synchronization of
action potentials and antagonist co-activations leading to an
improvement in dynamic force and power production (Folland
and Williams, 2007).
As discussed in the limitations, the duration of the training
intervention induced a shift in F-v profile (FVimb reduced by
more than one half), although some additional weeks of training
might have totally removed FVimb in some subjects, since the
time for adjustments at structural level (mainly related to F0)
typically require a longer period (Kenney et al., 2015) beyond the
more acute neuromuscular adaptations.

Velocity-Deficit Sub-group
Concerning the VD group, the specific training caused moderate
to extremely large increases in v0 (+17.9 ± 4.2%; ES = 2.37 ±
0.21), FVimb reduction (−20.1 ± 4.3%; ES = 2.20 ± 0.26) and
jump height (+12.7 ± 5.7%; ES = 0.93 ± 0.09), with a majority of
responders ( **Table 3** ; **Figures 1**, **2** ). This suggests that the selected
specific exercises for this group were effective for shifting F-v
profile in accordance with initial FVimb ( **Table 3** ; **Figures 1**, **2** )
and improving the maximal velocity end of the F-v relationship.
These findings are in agreement with other studies aiming at
specifically improving velocity qualities (Newton et al., 1996;
Argus et al., 2011; Markovic et al., 2011; Sheppard et al., 2011),
supporting the “principle of velocity specificity” as a specific
stimulus to promote velocity-specific neural training adaptations
(Kanehisa and Miyashita, 1983; Sale, 1988; Newton et al., 1996;
Paddon-Jones et al., 2001). Similarly to the FD sub-group, the
increase in v0 in the VD group was observed here in parallel with
a decrease in F0, so following the same interpretation as above,
the performance improvement can only be attributed to FVimb
reduction, and not to increased Pmax. It is almost certain that with
both a FVimb reduction and an increase in Pmax (so keeping F0
at similar level), improvements in performance would have been
greater.
The main exercise used in the VD group was the “horizontal
push” ( **Figure 3** ) exercise in which there was an almost total
elimination of the gravitational component. This could be
explained by the fact that power output developed during
maximal efforts is less dependent on muscle strength when the
exercise does not involve gravity (Minetti, 2002), as it would be
the case of a horizontal extension such as our horizontal push
exercise. This training exercise likely had a meaningful impact in
the extremely large increase in v0 observed for the VD group.
The main features of this exercise (almost null gravitational
component and limited time available for applying force)
makes it particularly suitable for the development of explosive
muscle contractions (rate of force development and maximal
velocity; Tillin and Folland, 2014). This “overspeed” exercise may
therefore be considered of great interest for improving velocity

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 8 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

FIGURE 3 | (A) Representation of starting position for horizontal push-off
exercise. (B) Representation of final position for horizontal push-off exercise.

capabilities and reducing the associated FVimb since it suppresses
the gravitational constraint (Markovic and Jaric, 2007; Sheppard
et al., 2011; Leontijevic et al., 2012; Vuk et al., 2012; Markovic
et al., 2013; Pazin et al., 2013; Suzovic et al., 2013) and helps
athletes reach lower limbs extensión velocity 20–30% higher than
the take-off velocity of a SJ (personal unpublished data; Markovic
et al., 2011). As a result, the most representative effect would be
to shift the early force-time curve to the left (50–100 first ms;
Oliveira et al., 2013, 2016). That said, from a practical standpoint,
we think that any exercise involving an external resistance force
lower than bodyweight can be effective. Although further studies
should investigate whether lighter loads have greater training
effects, these results are in line with studies about the influence
of training with no gravitational negative loads (Argus et al.,
2011; Markovic et al., 2011; Sheppard et al., 2011). Sheppard
et al. (2011) found that volleyball players who trained for 5
weeks with assisted jumps, significantly improved jump height
compared to subjects who performed regular jump training. They
reported that “assisted jumping” was useful at overloading the
velocity aspects of jump propulsión, which is similar to what
we intended to do with a specific work of horizontal push.
Similarly, (Markovic et al., 2011), reported a marked increase in
peak lower limb extension velocity resulting from a 7-week jump
training with negative loading (assisted jumps), supporting the
concept of velocity specificity in resistance training as in previous
ballistic power training studies (Sale, 1988; Markovic and Jaric,
2007; Cormie et al., 2010). Finally, Argus et al. (2011) observed
similar positive effects on jump height after a 4-week assisted

−
jumps ( 20% of body weight) training program. Interestingly,
these authors reported the individual changes, which show that
6 of the 9 participants in their study improved jump height
under this “velocity-oriented” program. The fact that these
subjects were highly trained rugby players (thus very likely with
a force-oriented F-v profile, and in turn a velocity deficit) may
explain the counterintuitive result showing that most of them
improved jump height after an assisted jump training program.
We speculate that most of these rugby players needed to correct
a velocity deficit to improve jump height, and this may explain
why they responded well to the assisted jump program.
Although our aim was not to investigate the neurophysiological mechanisms underpinning the changes observed
in the VD group, these may include a changes in neural
activation patterns (i.e., lowered motor unit recruitment
thresholds, improved motor unit firing frequency, and possibly
synchronization, greater and/or more effective recruitment

of fast-twitch muscle fibers) and enhanced intra- and intermuscular coordination (Sale, 1988; Behm and Sale, 1993;
VanCutsem et al., 1998; de Ruiter et al., 2004, 2006).
Another interesting yet secondary result was that in the
FD and VD groups, the decrease in FVimb was due to both
an increase in the targeted component of the F-v profile (i.e.,
F0 and v0, respectively), but also a decrease in the opposite
component. Subjects in the FD groups showed a large decrease
in v0 after training (−18.9 ± 11.8%) and subjects in the VD
group showed a decrease in F0 (−6.2 ± 3.3%). Although at
first sight it may seem that a training program resulting in a
decrease of a physical quality is counterproductive, but these
changes overall contributed here to the effective shift in the Fv profile toward the optimal value. As previously mentioned,
better improvements might have been observed if subjects had
both an increase in their weak component (e.g., F0 for the FD
group) and a maintainance of the other component (e.g., v0
for the FD group), which lead to an optimization of the F-v
profile (certainly slightly less fast than here) and an increase
in Pmax, both of them contributing independently to improve
performance. The training protocols proposed in this study did
not allow subjects presenting a F-v deficit to maintain at a similar
level the muscular quality initially considered as a “strength.”
The latter requires to keep the training quality considered as
a “strength” in addition to focus on reducting the “weakness,”
which was not done enough in present protocol. However, the
increase in performance obtained here without any large change
in Pmax well supports the interest to consider FVimb in training
focusing to improve ballistic performance.

Well-Balanced Sub-group
Regarding the WB group results, the training program
encompassed all the components of the force-velocity spectrum
with equal distribution, and resulted in increases in F0 (+1.8 ±
3.5%; ES = 0.38 ± 0.64) and v0 (+3.7 ± 4.1%; ES = 0.44 ± 0.41)
capabilities, with an overall maintainance of F-v profile (average
FVimb change of −0.5 ± 6.7%; ES = 0.11 ± 0.20). This group
showed a moderate jump height improvement (+7.2 ± 4.5%; ES
= 0.70 ± 0.36) mainly explained by the small increase in Pmax.
Thus, the training program proposed to this group resulted in an
overall shift of the entire F-v relationship to the right: increasing
Pmax while maintaining a very low FVimb, i.e., F-v profile close to
the optimal value. The findings for this group are in agreement
with previous studies using mixed resistance training loads
(Wilson et al., 1993; Toji et al., 1997; Harris et al., 2000; McBride
et al., 2002; Toji and Kaneko, 2004; Kotzamanidis et al., 2005;
Cormie et al., 2007; de Villarreal et al., 2011) to increase maximal
power output, and in turn ballistic performances.

Non-optimized Group
The “non-optimized” group performed a training program that
was similar to the WB group, and similar among subjects,
whatever their individual FVimb and thus training needs. This
resulted in a less clear changes in jump height (+2.3% on average
± 4.7%; ES: 0.14 ± 0.13, likely trivial), and substantial interindividual variability. Furthermore, only 10 subjects out of 18
improved jump height in this group (although only 7 out of

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 9 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

18 were beneficial responders, **Table 3** ) vs. all subjects in the
FD, VD and WB sub-groups. This result was associated with
variable changes (coefficient of variability of 200% or more) in
the F-v mechanical outputs: change in F0 was −2.3 ± 6.8%;
v0: +5.6 ± 11.9%; Pmax: +2.4 ± 6.1%; and FVimb: −5.5 ±
17.6%. These results show that when addressed as a group,
and not individually, the training program was not effective in
reducing each subject’s FVimb. On the contrary, this common
program induced positive changes for some subjects and negative
changes for others, and overall considerable variability in the
outcome for both mechanical features of the F-v profile and jump
performance ( **Table 3** ; **Figures 1**, **2** ). Comparatively, in terms of
jump height improvement, the number of responders in this nonoptimized group (7 out of 18) was much lower than for the
optimized sub-groups (all subjects of FD, VD, and WB groups,
i.e., 56 out of 56). It is important to note that the NO group
was composed of 18 subjects with different initial F-v profile
and FVimb before the training intervention (10 with force deficit
and 8 with velocity deficit) to match the distribution of the
optimized groups as much as possible. Assigning all subjects of an
intervention group to a common program aiming at increasing
jumping power and performance is the classical modus operandi
(Wilson et al., 1993; Harris et al., 2000; McBride et al., 2002;
Toji and Kaneko, 2004; Cormie et al., 2007, 2010), and these
studies also showed a great inter-individual variation in response
to the resistance training program. This high variability could
be interpreted as if the training program does not target the
initial FVimb of each subjects (as in our FD, VD, and WB
sub-groups), then subjects might not receive the most effective
training prescription on an individual basis, which in turn
results in variable outcomes when considering group results.
Depending on the interaction between subjects’ background and
the training program proposed, an experimental group may
include responders and non-responders in variable proportions
(e.g., Wilson et al., 1993; Gorostiaga et al., 1999; Harris et al.,
2000; McBride et al., 2002; Kotzamanidis et al., 2005; Cormie
et al., 2007, 2010; Chelly et al., 2009; Losnegard et al., 2011; de
Villarreal et al., 2011; Rønnestad et al., 2012, 2016; Smilios et al.,
2013). This has not been controlled for in previous studies, which
we think is a likely explanation for the high variability observed in
the outcome of most studies investigating the effects of strength
training on jump height. Thus, we suggest that the individual
F-v profile and the FVimb are taken into account as a starting
point for prescribing specific loads and training program for a
more effective training to improve jump performance (Tillin and
Folland, 2014; Morin and Samozino, 2016).

LIMITATIONS

Although this is the first study to tailor the strength training
program to the individual characteristics of the F-v profile,
it has limitations that should be discussed. First, our subject
recruitment led to a WB sub-group of only six subjects while
FD and VD sub-groups included 22 and 18 subjects, respectively.
Our personal experience (unpublished data) with hundredths of
athletes in various sports show that well-balanced F-v profile (i.e.,
FVimb close to 0%) are rare compared to subjects with a F-v

deficit (be it a force or a velocity deficit). However, the results
for these six individuals confirmed our hypothesis that a wellbalanced training would maintain their FVimb at low values,
while increasing their Pmax, and in turn their jump height. The
second and main limitation is that the fixed training duration
of 9 weeks for all subjects could be considered as not ideal. We
think that, just as the content of the training program, its duration
should also have been set on an individual basis. The duration of

the program should have been the duration necessary for each
individual to reach a FVimb close to 0. As shown in **Figure 1** and
**Table 3**, this 9-week duration was close to optimal for most of the
VD sub-group subjects, but not long enough for most FD subgroup subjects. We speculate that should the training duration
have also been individualized, the results of the intervention
would have been even better. We admit that, as explained in the
methods, this 9-week duration has been set under the influence
of previous studies, and we hope for further studies to show
an even more efficient optimized training should individualize
both the training content and the training duration, so that each
subject reduces his FVimb and/or increases his Pmax. This is, to
our opinion, one advantage of this approach: it allows a dynamic
adaptation to each individual’s response to training, both in terms
of training content and timing. Furthermore, as we observed
for only 2 subjects in this study (mid-program assessment of
F-v profile, data not shown), should subjects adapt faster than
others and change sub-group (e.g., from high force deficit to
low force deficit) within the pre-set training period, intermediate
assessments may easily allow to finely tune the training program
and adapt it to the response kinetics of each individual. Finally,
our study is focused on vertical F-v profile and jump performance
only, which is the simplest and most representative movement
for ballistic performances. An interesting point would be to
test whether a more optimal jumping F-v profile would be
associated with improved performance in other maximal effort
contexts such as sprint cycling or running. The latter is a major
physical component of performance in many sports, and many
studies focused on the transfer between lower limbs strength
training and sprint running performance (Cronin and Sleivert,
2005; Seitz et al., 2014; Contreras et al., 2016). This would be
a complementary step for a better understanding of F-v profile
based training for new insights in strength and conditioning
practice. Finally, it is worth highlighting that when we are
referring to optimized training and performance improvement,
we mean ballistic performances performed at body mass without
resistance (i.e., when the aim is to maximally accelerate his own
mass, and in particular vertical jumping). We chose vertical jump
performance in the present study since it is the simplest task
which well represents ballistic movements and it is a key direct or
indirect physical performance variable in many sport activities.

CONCLUSION

An optimized and individualized training program specifically
addressing the force-velocity imbalance is more efficient at
improving jumping performance than a traditional resistance
training common to all subjects regardless of their force-velocity
imbalance and optimal force-velocity profile. FVimb could

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 10 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

therefore be considered as a potentially useful variable for
prescribing optimal resistance training to improve ballistic
(e.g., jumping) performance. As discussed recently (Morin and
Samozino, 2016), this force-velocity approach may help improve
the training practice for performance in explosive push-off
actions like jumping, through a more efficient monitoring
and understanding of the individual determinants of athletic
performance. The experimental results obtained in the present
study confirmed the theoretical principles of the optimized
training approach (Samozino et al., 2014; Morin and Samozino,
2016\) that jump performance depends not only on maximal
power output, but on an optimal force-velocity profile.

AUTHOR CONTRIBUTIONS

Conceived and designed the experiments: PJ, PS, MB, JM.
Performed experiments: PJ. Analyzed data: PJ, PS, MB, JM.
Interpreted results of research: PJ, PS, MB, JM. Drafted
manuscript and prepared tables/figures: PJ, JM. Edited, critically

REFERENCES

Argus, C. K., Gill, N. D., Keogh, J. W. L., Blazevich, A. J., and Hopkins,
W. G. (2011). Kinetic and training comparisons between assisted, resisted,
and free countermovement jumps. J. Strength Cond. Res. 25, 2219–2227.
[doi: 10.1519/JSC.0b013e3181f6b0f4](https://doi.org/10.1519/JSC.0b013e3181f6b0f4)
Baechle, T., and Earle, R. (2000). Essentials of Strength Training and Conditioning,
2nd Edn. Champaign, IL: Human Kinetics.
Batterham, A. M., and Hopkins, W. G. (2006). Making meaningful
inferences about magnitudes. Int. J. Sports Physiol. Perform. 1, 50–57.
[doi: 10.1123/ijspp.1.1.50](https://doi.org/10.1123/ijspp.1.1.50)
Behm, D. G., and Sale, D. G. (1993). Velocity specificity of resistance training.
[Sports Med. 15, 374–388. doi: 10.2165/00007256-199315060-00003](https://doi.org/10.2165/00007256-199315060-00003)
Chelly, M. S., Fathloun, M., Cherif, N., Ben Amar, M., Tabka, Z., and
Van Praagh, E. (2009). Effects of a back squat training program on
leg power, jump, and sprint performances in junior soccer players.
J. Strength Cond. Res. 23, 2241–2249. doi: 10.1519/JSC.0b013e3181b

86c40

Contreras, B., Vigotsky, A. D., Schoenfeld, B. J., Beardsley, C., McMaster,
D. T., Reyneke, J., et al. (2016). Effects of a six-week hip thrust
versus front squat resistance training program on performance in
adolescent males: a randomized-controlled trial. J. Strength Cond. Res.
[doi: 10.1519/jsc.0000000000001510. \[Epub ahead of print\].](https://doi.org/10.1519/jsc.0000000000001510)
Cormie, P., McCaulley, G. O., and McBride, J. M. (2007). Power versus strengthpower jump squat training: influence on the load-power relationship.
Med. Sci. Sports Exerc. 39, 996–1003. doi: 10.1097/mss.0b013e31804

08e0c

Cormie, P., McGuigan, M. R., and Newton, R. U. (2010). Adaptations
in athletic performance after ballistic power versus strength training.
Med. Sci. Sports Exerc. 42, 1582–1598. doi: 10.1249/MSS.0b013e3181d

2013a

Cormie, P., McGuigan, M. R., and Newton, R. U. (2011). Developing
maximal neuromuscular power: part 2 - training considerations for
improving maximal power production. Sports Med. 41, 125–146.
[doi: 10.2165/11538500-000000000-00000](https://doi.org/10.2165/11538500-000000000-00000)

Cronin, J., and Sleivert, G. (2005). Challenges in understanding the influence of
maximal power training on improving athletic performance. Sport. Med. 35,
[213–234. doi: 10.2165/00007256-200535030-00003](https://doi.org/10.2165/00007256-200535030-00003)

de Lacey, J., Brughelli, M., McGuigan, M., Hansen, K., Samozino, P., and Morin,
J.-B. (2014). The effects of tapering on power-force-velocity profiling and jump
performance in professional rugby league players. J. Strength Cond. Res. 28,
[3567–3570. doi: 10.1519/JSC.0000000000000572](https://doi.org/10.1519/JSC.0000000000000572)

revised paper, and approved final version of manuscript: PJ, PS,
MB, JM.

ACKNOWLEDGMENTS

This study was funded by the Spanish Ministry of Education,
Culture and Sport (National Plan 2015; grant reference
CAS15/00171) with the National Program for “Mobility stays
abroad “José Castillejo” for young doctors.” The experimenters
would like to thank Adrián Castaño-Zambudio, Víctor
Cuadrado-Peñafiel, Antonio Del Aguila, Salustiano Campuzano,
and Pete Griffith for their technical support, and the subjects for
having performed this demanding experiment with enthusiasm.
We also thank the numerous colleagues and students who
discussed these issues with us over the recent years. These
discussions were a very important source of reflection in our
writing process. Some of these results have been presented at the
2016 European Congress of Sport Science.

de Ruiter, C. J., Kooistra, R. D., Paalman, M. I., and de Haan, A. (2004).
Initial phase of maximal voluntary and electrically stimulated knee extension
torque development at different knee angles. J. Appl. Physiol. 97, 1693–1701.
[doi: 10.1152/japplphysiol.00230.2004](https://doi.org/10.1152/japplphysiol.00230.2004)
de Ruiter, C. J., Van Leeuwen, D., Heijblom, A., Bobbert, M. F., and
de Haan, A. (2006). Fast unilateral isometric knee extension torque
development and bilateral jump height. Med. Sci. Sports Exerc. 38, 1843–1852.
[doi: 10.1249/01.mss.0000227644.14102.50](https://doi.org/10.1249/01.mss.0000227644.14102.50)

de Villarreal, E. S., Izquierdo, M., and Gonzalez-Badillo, J. J. (2011). Enhancing
jump performance after combined vs. maximal power, heavy-resistance,
and plyometric training alone. J. Strength Cond. Res. 25, 3274–3281.
[doi: 10.1519/JSC.0b013e3182163085](https://doi.org/10.1519/JSC.0b013e3182163085)
Djuric, S., Cuk, I., Sreckovic, S., Mirkov, D., Nedeljkovic, A., and Jaric,
S. (2016). Selective effects of training against weight and inertia on
muscle mechanical properties. Int. J. Sports Physiol. Perform. 11, 927–932.
[doi: 10.1123/ijspp.2015-0527](https://doi.org/10.1123/ijspp.2015-0527)
Fleck, S., and Kraemer, W. J. (2004). Designing Resistance Training Programs, 3rd
Edn. Champaign, IL: Human Kinetics.
Folland, J. P., and Williams, A. G. (2007). The adaptations to strength
training. Sport. Med. 37, 145–168. doi: 10.2165/00007256-200737020
00004

Frost, D. M., Cronin, J., and Newton, R. U. (2010). A biomechanical evaluation
of resistance fundamental concepts for training and sports performance. Sports
[Med. 40, 303–326. doi: 10.2165/11319420-000000000-00000](https://doi.org/10.2165/11319420-000000000-00000)
Giroux, C., Rabita, G., Chollet, D., and Guilhem, G. (2015). What is the best
method for assessing lower limb force-velocity relationship? Int. J. Sports Med.
[36, 143–149. doi: 10.1055/s-0034-1385886](https://doi.org/10.1055/s-0034-1385886)
Giroux, C., Rabita, G., Chollet, D., and Guilhem, G. (2016). Optimal balance
between force and velocity differs among world-class athletes. J. Appl. Biomech.
[32, 59–68. doi: 10.1123/jab.2015-0070](https://doi.org/10.1123/jab.2015-0070)
Gorostiaga, E. M., Izquierdo, M., Iturralde, P., Ruesta, M., and Ibáñez, J.
(1999). Effects of heavy resistance training on maximal and explosive force
production, endurance and serum hormones in adolescent handball players.
Eur. J. Appl. Physiol. Occup. Physiol. 80, 485–493. doi: 10.1007/s0042100

50622

Harris, G. R., Stone, M. H., O’Bryant, H. S., Proulx, C. M., and Johnson,
R. L. (2000). Short term performance effects of high speed, high force
or combined weight-training methods. J. Strength Cond. Res. 14, 14–20.
[doi: 10.1519/1533-4287(2000)014\<0014:STPEOH>2.0.CO;2](<https://doi.org/10.1519/1533-4287(2000)014%3C0014:STPEOH%3E2.0.CO;2>)
Hopkins, W. G. (2004). How to interpret changes in an athletic performance
[test. Sportsciences 8, 1–7. Available online at: http://www.sportsci.org/jour/04/](http://www.sportsci.org/jour/04/wghtests.htm)
[wghtests.htm](http://www.sportsci.org/jour/04/wghtests.htm)

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 11 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

Hopkins, W. G., Marshall, S. W., Batterham, A. M., and Hanin, J. (2009).
Progressive statistics for studies in sports medicine and exercise science. Med.
[Sci. Sports Exerc. 41, 3–13. doi: 10.1249/MSS.0b013e31818cb278](https://doi.org/10.1249/MSS.0b013e31818cb278)
Jiménez-Reyes, P., Samozino, P., Cuadrado-Pe-afiel, V., Conceição, F.,
González-Badillo, J. J., and Morin, J.-B. (2014). Effect of countermovement
on power-force-velocity profile. Eur. J. Appl. Physiol. 114, 2281–2288.
[doi: 10.1007/s00421-014-2947-1](https://doi.org/10.1007/s00421-014-2947-1)

Jiménez-Reyes, P., Samozino, P., Pareja-Blanco, F., Conceição, F., CuadradoPe-afiel, V., González-Badillo, J. J., et al. (2016). Validity of a simple method
for measuring force-velocity-power profile in countermovement jump. Int.
[J. Sports Physiol. Perform. doi: 10.1123/ijspp.2015-0484. Available online](https://doi.org/10.1123/ijspp.2015-0484)
at: [http://journals.humankinetics.com/doi/abs/10.1123/ijspp.2015-0484?](http://journals.humankinetics.com/doi/abs/10.1123/ijspp.2015-0484?journalCode=ijspp)
[journalCode=ijspp](http://journals.humankinetics.com/doi/abs/10.1123/ijspp.2015-0484?journalCode=ijspp)
Kanehisa, H., and Miyashita, M. (1983). Specificity of velocity in strength training.
[Eur. J. Appl. Physiol. Occup. Physiol. 52, 104–106. doi: 10.1007/BF00429034](https://doi.org/10.1007/BF00429034)
Kenney, W., Wilmore, J., and Costill, D. L. (2015). Physiology of Sport and Exercise.
6th Edn. Champaign, IL: Human Kinetics.
Kotzamanidis, C., Chatzopoulos, D., Michailidis, C., Papaiakovou, G., and Patikas,
D. (2005). The effect of a combined high-intensity strength and speed training
program on the running and jumping ability of soccer players. J. Strength Cond.
[Res. 19, 369–375. doi: 10.1519/R-14944.1](https://doi.org/10.1519/R-14944.1)
Leontijevic, B., Pazin, N., Bozic, P. R., Kukolj, M., Ugarkovic, D., and
Jaric, S. (2012). Effects of loading on maximum vertical jumps: selective
effects of weight and inertia. J. Electromyogr. Kinesiol. 22, 286–293.
[doi: 10.1016/j.jelekin.2011.12.002](https://doi.org/10.1016/j.jelekin.2011.12.002)
Losnegard, T., Mikkelsen, K., Rønnestad, B. R., Hallén, J., Rud, B., and Raastad,
T. (2011). The effect of heavy strength training on muscle mass and physical
performance in elite cross country skiers. Scand. J. Med. Sci. Sports 21, 389–401.
[doi: 10.1111/j.1600-0838.2009.01074.x](https://doi.org/10.1111/j.1600-0838.2009.01074.x)
Markovic, G. (2007). Does plyometric training improve vertical jump height?
A meta-analytical review. Br. J. Sports Med. 41, 349–355. discussion: 355.
[doi: 10.1136/bjsm.2007.035113](https://doi.org/10.1136/bjsm.2007.035113)
Markovic, G., and Jaric, S. (2007). Positive and negative loading and mechanical
output in maximum vertical jumping. Med. Sci. Sports Exerc. 39, 1757–1764.
[doi: 10.1249/mss.0b013e31811ece35](https://doi.org/10.1249/mss.0b013e31811ece35)

Markovic, G., Vuk, S., and Jaric, S. (2011). Effects of jump training with negative
versus positive loading on jumping mechanics. Int. J. Sports Med. 32, 365–372.
[doi: 10.1055/s-0031-1271678](https://doi.org/10.1055/s-0031-1271678)

Markovic, S., Mirkov, D. M., Knezevic, O. M., and Jaric, S. (2013). Jump training
with different loads: effects on jumping performance and power output. Eur. J.
[Appl. Physiol. 113, 2511–2521. doi: 10.1007/s00421-013-2688-6](https://doi.org/10.1007/s00421-013-2688-6)
McBride, J. M., Skinner, J. W., Schafer, P. C., Haines, T. L., and Kirby, T. J. (2010).
Comparison of kinetic variables and muscle activity during a squat vs. a box
[squat. J. Strength Cond. Res. 24, 3195–3199. doi: 10.1519/JSC.0b013e3181f6399a](https://doi.org/10.1519/JSC.0b013e3181f6399a)
McBride, J. M., Triplett-McBride, T., Davie, A., and Newton, R. U. (2002).
The effect of heavy- vs. light-load jump squats on the development
of strength, power, and speed. J. Strength Cond. Res. 16, 75–82.
[doi: 10.1519/00124278-200202000-00011](https://doi.org/10.1519/00124278-200202000-00011)

Minetti, A. E. (2002). On the mechanical power of joint extensions as affected by
the change in muscle force (or cross-sectional area), ceteris paribus. Eur. J. Appl.
[Physiol. 86, 363–369. doi: 10.1007/s00421-001-0554-4](https://doi.org/10.1007/s00421-001-0554-4)
Morin, J. B., and Samozino, P. (2016). Interpreting power-force-velocity profiles
for individualized and specific training. Int. J. Sports Physiol. Perform. 11,
[267–272. doi: 10.1123/ijspp.2015-0638](https://doi.org/10.1123/ijspp.2015-0638)
Newton, R. U., and Kraemer, W. J. (1994). Developing explosive muscular power:
implications for a mixed methods training strategy. Strength Cond. 16, 20–31.
[doi: 10.1519/1073-6840(1994)016\<0020:DEMPIF>2.3.CO;2](<https://doi.org/10.1519/1073-6840(1994)016$%3C$0020:DEMPIF$%3E$2.3.CO;2>)
Newton, R. U., Kraemer, W. J., Hakkinen, K., Humphries, B. J., and Murphy, A.
J. (1996). Kinematics, kinetics, and muscle activation during explosive upper
[body movements. J. Appl. Biomech. 12, 37–43. doi: 10.1123/jab.12.1.31](https://doi.org/10.1123/jab.12.1.31)
Oliveira, A. S., Corvino, R. B., Caputo, F., Aagaard, P., and Denadai, B.
S. (2016). Effects of fast-velocity eccentric resistance training on early
and late rate of force development. Eur. J. Sport Sci. 16, 199–205.
[doi: 10.1080/17461391.2015.1010593](https://doi.org/10.1080/17461391.2015.1010593)

Oliveira, F. B. D., Oliveira, A. S. C., Rizatto, G. F., and Denadai, B. S. (2013).
Resistance training for explosive and maximal strength: effects on early and late
rate of force development. J. Sports Sci. Med. 12, 402–408.

Paddon-Jones, D., Leveritt, M., Lonergan, A., and Abernethy, P.
(2001). Adaptation to chronic eccentric exercise in humans: the
influence of contraction velocity. Eur. J. Appl. Physiol. 85, 466–471.
[doi: 10.1007/s004210100467](https://doi.org/10.1007/s004210100467)

Pazin, N., Berjan, B., Nedeljkovic, A., Markovic, G., and Jaric, S. (2013). Power
output in vertical jumps: does optimum loading depend on activity profiles?
[Eur. J. Appl. Physiol. 113, 577–589. doi: 10.1007/s00421-012-2464-z](https://doi.org/10.1007/s00421-012-2464-z)
Peterson, M. D., Rhea, M. R., and Alvar, B. A. (2004). Maximizing
strength development in athletes: a meta-analysis to determine
the dose-response relationship. J. Strength Cond. Res. 18, 377–382.
[doi: 10.1519/00124278-200405000-00031](https://doi.org/10.1519/00124278-200405000-00031)

Rhea, M. R., Alvar, B. A., and Burkett, L. N. (2002). Single versus multiple sets for
strength: a meta-analysis to address the controversy. Res. Q. Exerc. Sport 73,
[485–488. doi: 10.1080/02701367.2002.10609050](https://doi.org/10.1080/02701367.2002.10609050)

Rhea, M. R., Alvar, B. A., Burkett, L. N., and Ball, S. D. (2003). A meta-analysis to
determine the dose response for strength development. Med. Sci. Sports Exerc.
[35, 456–464. doi: 10.1249/01.MSS.0000053727.63505.D4](https://doi.org/10.1249/01.MSS.0000053727.63505.D4)
Rønnestad, B. R., Hansen, J., and Nygaard, H. (2016). 10 weeks of heavy strength
training improves performance-related measurements in elite cyclists. J. Sports
[Sci. doi: 10.1080/02640414.2016.1215499. \[Epub ahead of print\].](https://doi.org/10.1080/02640414.2016.1215499)
Rønnestad, B. R., Kojedal, O., Losnegard, T., Kvamme, B., and Raastad, T.
(2012). Effect of heavy strength training on muscle thickness, strength, jump
performance, and endurance performance in well-trained Nordic Combined
athletes. Eur. J. Appl. Physiol. 112, 2341–2352. doi: 10.1007/s00421-011
2204-9

Sale, D. G. (1988). Neural adaptation to resistance training. Med. Sci. Sports Exerc.
[20, S135–S145. doi: 10.1249/00005768-198810001-00009](https://doi.org/10.1249/00005768-198810001-00009)
Samozino, P., Edouard, P., Sangnier, S., Brughelli, M., Gimenez, P., and
Morin, J. B. (2014). Force-velocity profile: Imbalance determination and
effect on lower limb ballistic performance. Int. J. Sports Med. 35, 505–510.
[doi: 10.1055/s-0033-1354382](https://doi.org/10.1055/s-0033-1354382)

Samozino, P., Morin, J. B., Hintzy, F., and Belli, A. (2008). A simple method for
measuring force, velocity and power output during squat jump. J. Biomech. 41,
[2940–2945. doi: 10.1016/j.jbiomech.2008.07.028](https://doi.org/10.1016/j.jbiomech.2008.07.028)
Samozino, P., Morin, J. B., Hintzy, F., and Belli, A. (2010). Jumping
ability: a theoretical integrative approach. J. Theor. Biol. 264, 11–18.
[doi: 10.1016/j.jtbi.2010.01.021](https://doi.org/10.1016/j.jtbi.2010.01.021)
Samozino, P., Rejc, E., Di Prampero, P. E., Belli, A., and Morin, J.-B. (2012).
Optimal force-velocity profile in ballistic movements–altius: citius or fortius?
[Med. Sci. Sports Exerc. 44, 313–322. doi: 10.1249/MSS.0b013e31822d757a](https://doi.org/10.1249/MSS.0b013e31822d757a)
Seitz, L. B., Reyes, A., Tran, T. T., de Villarreal, E. S., and Haff, G.
G. (2014). Increases in lower-body strength transfer positively to sprint
performance: a systematic review with meta-analysis. Sport. Med. 44,
[1693–1702. doi: 10.1007/s40279-014-0227-1](https://doi.org/10.1007/s40279-014-0227-1)

Sheppard, J. M., Dingley, A. A., Janssen, I., Spratford, W., Chapman, D. W.,
and Newton, R. U. (2011). The effect of assisted jumping on vertical jump
height in high-performance volleyball players. J. Sci. Med. Sport 14, 85–89.
[doi: 10.1016/j.jsams.2010.07.006](https://doi.org/10.1016/j.jsams.2010.07.006)
Smilios, I., Sotiropoulos, K., Christou, M., Douda, H., Spaias, A., and Tokmakidis,
S. P. (2013). Maximum power training load determination and its effects on
load-power relationship, maximum strength, and vertical jump performance. J.
[Strength Cond. Res. 27, 1223–1233. doi: 10.1519/JSC.0b013e3182654a1c](https://doi.org/10.1519/JSC.0b013e3182654a1c)
Suzovic, D., Markovic, G., Pasic, M., and Jaric, S. (2013). Optimum load in various
vertical jumps support the maximum dynamic output hypothesis. Int. J. Sports
[Med. 34, 1007–1014. doi: 10.1055/s-0033-1337942](https://doi.org/10.1055/s-0033-1337942)
Tillin, N. A., and Folland, J. P. (2014). Maximal and explosive strength training
elicit distinct neuromuscular adaptations, specific to the training stimulus. Eur.
[J. Appl. Physiol. 114, 365–374. doi: 10.1007/s00421-013-2781-x](https://doi.org/10.1007/s00421-013-2781-x)
Toji, H., and Kaneko, M. (2004). Effect of multiple-load training on
the force-velocity relationship. J. Strength Cond. Res. 18, 792–795.
[doi: 10.1519/00124278-200411000-00019](https://doi.org/10.1519/00124278-200411000-00019)

Toji, H., Suei, K., and Kaneko, M. (1997). Effects of combined training loads on
relations among force, velocity, and power development. Can. J. Appl. Physiol.
[22, 328–336. doi: 10.1139/h97-021](https://doi.org/10.1139/h97-021)
VanCutsem, M., Duchateau, J., and Hainaut, K. (1998). Changes in single motor
unit behaviour contribute to the increase in contraction speed after dynamic
training in humans. J. Physiol. 513(Pt 1), 295–305.

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 12 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)

Jiménez-Reyes et al. Force-Velocity Optimized Training for Jump Performance

Vuk, S., Markovic, G., and Jaric, S. (2012). External loading and maximum
dynamic output in vertical jumping: the role of training history. Hum. Mov.
[Sci. 31, 139–151. doi: 10.1016/j.humov.2011.04.007](https://doi.org/10.1016/j.humov.2011.04.007)
Wilson, G. J., Newton, R. U., Murphy, A. J., and Humphries, B. J. (1993). The
optimal training load for the development of dynamic athletic performance.
[Med. Sci. Sports Exerc. 25, 1279–1286. doi: 10.1249/00005768-199311000-00013](https://doi.org/10.1249/00005768-199311000-00013)
Winter, E. M. (2005). Jumping: power or impulse? Med. Sci. Sport. Exerc. 37, 523.
[doi: 10.1249/01.MSS.0000155703.50713.26](https://doi.org/10.1249/01.MSS.0000155703.50713.26)

Yamauchi, J., and Ishii, N. (2007). Relations between force-velocity characteristics
of the knee-hip extension movement and vertical jump performance.
J. Strength Cond. Res. 21, 703–709. doi: 10.1519/00124278-200708000
00009

Zaras, N., Spengos, K., Methenitis, S., Papadopoulos, C., Karampatsos,
G., Georgiadis, G., et al. (2013). Effects of strength vs. Ballistic

power training on throwing performance. J. Sport. Sci. Med. 12,

130–137.

**Conflict of Interest Statement:** The authors declare that the research was
conducted in the absence of any commercial or financial relationships that could
be construed as a potential conflict of interest.

Copyright © 2017 Jiménez-Reyes, Samozino, Brughelli and Morin. This is an open[access article distributed under the terms of the Creative Commons Attribution](http://creativecommons.org/licenses/by/4.0/)
[License (CC BY). The use, distribution or reproduction in other forums is permitted,](http://creativecommons.org/licenses/by/4.0/)
provided the original author(s) or licensor are credited and that the original
publication in this journal is cited, in accordance with accepted academic practice.
No use, distribution or reproduction is permitted which does not comply with these

terms.

[Frontiers in Physiology | www.frontiersin.org](http://www.frontiersin.org/Physiology) 13 [January 2017 | Volume 7 | Article 677](http://www.frontiersin.org/Physiology/archive)
